pub fn find_inherited_attribute(
_doc: &PostDocument,
node: &Node,
attribute: &str,
) -> Option<String>Expand description
Find an inherited attribute by walking up the LaTeXML ancestor chain.
Port of find_inherited_attribute.
pub fn find_inherited_attribute(
_doc: &PostDocument,
node: &Node,
attribute: &str,
) -> Option<String>Find an inherited attribute by walking up the LaTeXML ancestor chain.
Port of find_inherited_attribute.